@@ -48,8 +48,9 @@
 ArArch::ArArch( ArkWidget *_gui, const QString & _fileName )
   : Arch(_gui, _fileName )
 {
-  m_archiver_program = "ar";
-  verifyCompressUtilityIsAvailable(m_archiver_program);
+  m_archiver_program = m_unarchiver_program = "ar";
+  verifyCompressUtilityIsAvailable( m_archiver_program );
+  verifyUncompressUtilityIsAvailable( m_unarchiver_program );
 
   // Do not set headerString - there is none for Ar
   m_numCols = 5;
