@@ -65,7 +65,7 @@ static KCmdLineOptions option[] =
 extern "C" KDE_EXPORT int kdemain( int argc, char *argv[]  )
 {
 	KAboutData aboutData( "ark", I18N_NOOP( "Ark" ),
-	                      "2.6.3", I18N_NOOP( "KDE Archiving tool" ),
+	                      "2.6.4", I18N_NOOP( "KDE Archiving tool" ),
 	                      KAboutData::License_GPL,
 	                      I18N_NOOP( "(c) 1997-2006, The Various Ark Developers" )
 	                    );
@@ -75,7 +75,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char *argv[]  )
 	                     "henrique.pinto@kdemail.net" );
 	aboutData.addAuthor( "Charis Kouzinopoulos",
 	                     0,
-	                     "haris@mpa.gr" );
+	                     "kouzinopoulos@gmail.com" );
 	aboutData.addAuthor( "Helio Chissini de Castro",
 	                     I18N_NOOP( "Former maintainer" ),
 	                     "helio@kde.org" );
