@@ -60,15 +60,18 @@ RarArch::RarArch( ArkWidget *_gui, const QString & _fileName )
   {
     // If it is, then use it as archiver and unarchiver
     m_archiver_program = m_unarchiver_program = "rar";
+    verifyCompressUtilityIsAvailable( m_archiver_program );
+    verifyUncompressUtilityIsAvailable( m_unarchiver_program );
   }
   else
   {
     // If rar is not available, try to use unrar to open the archive read-only
-    m_archiver_program = m_unarchiver_program = "unrar";
+    m_unarchiver_program = "unrar";
+    verifyUncompressUtilityIsAvailable( m_unarchiver_program );
     setReadOnly( true );
   }
 
-  verifyUtilityIsAvailable( m_archiver_program );
+
 
   m_headerString = "-------------------------------------------------------------------------------";
 
@@ -95,7 +98,7 @@ bool RarArch::processLine( const QCString &line )
   list << l2[ 2 ]; // ratio
 
   QStringList date =  QStringList::split( '-', l2[ 3 ] );
-  list << ArkUtils::fixYear( date[ 2 ].latin1() ) + "-" + date[ 1 ] + "-" + date [ 0 ] + " " + l2[4]; // date
+  list << ArkUtils::fixYear( date[ 2 ].latin1() ) + '-' + date[ 1 ] + '-' + date [ 0 ] + ' ' + l2[4]; // date
   list << l2[ 5 ]; // attributes
   list << l2[ 6 ]; // crc
   list << l2[ 7 ]; // method
@@ -116,7 +119,7 @@ void RarArch::open()
   m_finished = false;
 
   KProcess *kp = m_currentProcess = new KProcess;
-  *kp << m_archiver_program << "v" << "-c-" << m_filename;
+  *kp << m_unarchiver_program << "v" << "-c-" << m_filename;
 
   connect( kp, SIGNAL( receivedStdout(KProcess*, char*, int) ),
            SLOT( slotReceivedTOC(KProcess*, char*, int) ) );
@@ -222,7 +225,7 @@ void RarArch::unarchFileInternal()
   *kp << m_unarchiver_program << "x";
 
   if ( !m_password.isEmpty() )
-    *kp << "-p=" + m_password;
+    *kp << "-p" + m_password;
 
   if ( !ArkSettings::extractOverwrite() )
   {
