@@ -1,5 +1,5 @@
 /*
-    $Id: dlabel.cpp 367977 2004-12-03 00:55:31Z kniederk $
+    $Id: dlabel.cpp 490596 2005-12-22 13:05:45Z scripty $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -19,7 +19,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -38,6 +38,8 @@ DispLogic::DispLogic(QWidget *parent, const char *name,
 		     KActionCollection *coll)
   :KCalcDisplay(parent,name), _history_index(0)
 {
+	KNumber::setDefaultFloatOutput(true);
+	KNumber::setDefaultFractionalInput(true);
 	_back = KStdAction::undo(this, SLOT(history_back()), coll);
 	_forward = KStdAction::redo(this, SLOT(history_forward()), coll);
 
@@ -78,10 +80,10 @@ void DispLogic::update_from_core(CalcEngine const &core,
 				 bool store_result_in_history)
 {
 	bool tmp_error;
-	CALCAMNT output = core.lastOutput(tmp_error);
+	KNumber const & output = core.lastOutput(tmp_error);
 	if(tmp_error) sendEvent(EventError);
 	if (setAmount(output)  &&  store_result_in_history  &&
-	    output != 0)
+	    output != KNumber::Zero)
 	{
 	  // add this latest value to our history
 	  _history_list.insert(_history_list.begin(), output);
@@ -169,13 +171,14 @@ void DispLogic::history_forward()
 void DispLogic::history_back()
 {
 	Q_ASSERT(! _history_list.empty());
-	Q_ASSERT(_history_index < int(_history_list.size()));
+	Q_ASSERT( _history_index < static_cast<int>(_history_list.size()) );
 
 	setAmount(_history_list[_history_index]);
 
 	_history_index ++;
 	
-	if(_history_index == int(_history_list.size())) _back->setEnabled(false);
+	if( _history_index == static_cast<int>(_history_list.size()) )
+		_back->setEnabled(false);
 	_forward->setEnabled(true);
 }
 
