@@ -1,6 +1,6 @@
 /*
 
- $Id: dlabel.h 367977 2004-12-03 00:55:31Z kniederk $
+ $Id: dlabel.h 490596 2005-12-22 13:05:45Z scripty $
 
  KCalc 
 
@@ -20,7 +20,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
  */
 
@@ -30,7 +30,6 @@
 
 #include <qvaluevector.h>
 #include "kcalcdisplay.h"
-#include "kcalctype.h"
 
 class CalcEngine;
 class KAction;
@@ -55,7 +54,7 @@ private slots:
 	void history_forward(void);
 
 private:
-	QValueVector<CALCAMNT> _history_list;
+	QValueVector<KNumber> _history_list;
 	int _history_index;
 
 	KAction *_forward;
