@@ -75,10 +75,10 @@ private:
 	DCOPRef *kmixClient, *kmixWindow;
 
 	int m_progress;
-	int m_volume, m_oldVolume;
+	long m_volume, m_oldVolume;
 	bool m_mute;
 
-	int m_maxVolume, m_minVolume;
+	long m_maxVolume, m_minVolume;
 
 	Monitor::DisplayType m_displayType;
 };
