@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef KSIMVIEW_H
@@ -26,6 +26,7 @@
 #include <dcopobject.h>
 
 #include <kpanelextension.h>
+#include <kdelibs_export.h>
 
 class QBoxLayout;
 class QHBoxLayout;
@@ -45,7 +46,7 @@ namespace KSim
   class ConfigDialog;
   class ChangedPluginList;
 
-  class MainView : public QWidget, virtual public DCOPObject
+  class KDE_EXPORT MainView : public QWidget, virtual public DCOPObject
   {
     Q_OBJECT
     K_DCOP
@@ -57,7 +58,6 @@ namespace KSim
       ~MainView();
 
       virtual void show();
-      void cleanup();
 
       KSim::Config *config() const;
       void makeDirs();
@@ -90,6 +90,8 @@ namespace KSim
       void destroyPref();
 
     private:
+      void cleanup();
+	  
       KSim::Sysinfo *m_sysinfo;
       KSim::Label *m_hostLabel;
       KSim::Frame *m_leftFrame;
